[−][src]Crate yadf
A collection of functions and structs to find duplicate files.
Example :
Find, display, and report, all the duplicate files at the given path :
let files_counter = yadf::find_dupes::<twox_hash::XxHash64>(".".as_ref(), None); print!("{}", files_counter.display::<yadf::Fdupes>()); eprintln!("{}", yadf::Report::from(&files_counter));
Modules
| fs | Inner parts of |
Structs
| DirEntry | Serialization wrapper for |
| Fdupes | Display marker. |
| Machine | Display marker. |
| Report | Extract informations from a |
| TreeBag | Counter structure. |
Functions
| find_dupes | This will attemps a complete scan of every file, within the given size constraints, at the given path. |