pub struct AsyncRead {
pub handle: FileHandle,
pub read_len: usize,
}Fields
handle: FileHandleread_len: usizeTrait Implementations
Sourceimpl Archive for AsyncReadwhere
FileHandle: Archive,
usize: Archive,
impl Archive for AsyncReadwhere
FileHandle: Archive,
usize: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedAsyncRead
type Archived = ArchivedAsyncRead
The archived representation of this type. Read more
Sourcetype Resolver = AsyncReadResolver
type Resolver = AsyncReadResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for AsyncRead
impl BlockingArchive for AsyncRead
Sourceimpl<__D: Fallible + ?Sized> Deserialize<AsyncRead, __D> for Archived<AsyncRead>where
FileHandle: Archive,
<FileHandle as Archive>::Archived: Deserialize<FileHandle, __D>,
usize: Archive,
<usize as Archive>::Archived: Deserialize<usize, __D>,
impl<__D: Fallible + ?Sized> Deserialize<AsyncRead, __D> for Archived<AsyncRead>where
FileHandle: Archive,
<FileHandle as Archive>::Archived: Deserialize<FileHandle, __D>,
usize: Archive,
<usize as Archive>::Archived: Deserialize<usize, __D>,