pub struct AsyncWrite {
pub handle: FileHandle,
pub buffer: Vec<u8>,
}Fields
handle: FileHandlebuffer: Vec<u8>Trait Implementations
Sourceimpl Archive for AsyncWrite
impl Archive for AsyncWrite
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedAsyncWrite
type Archived = ArchivedAsyncWrite
The archived representation of this type. Read more
Sourcetype Resolver = AsyncWriteResolver
type Resolver = AsyncWriteResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for AsyncWrite
impl BlockingArchive for AsyncWrite
Sourceimpl Debug for AsyncWrite
impl Debug for AsyncWrite
Sourceimpl<__D: Fallible + ?Sized> Deserialize<AsyncWrite, __D> for Archived<AsyncWrite>where
FileHandle: Archive,
<FileHandle as Archive>::Archived: Deserialize<FileHandle, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<AsyncWrite, __D> for Archived<AsyncWrite>where
FileHandle: Archive,
<FileHandle as Archive>::Archived: Deserialize<FileHandle, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<AsyncWrite, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<AsyncWrite, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for AsyncWrite
impl MessageId for AsyncWrite
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for AsyncWrite
impl<__S: Fallible + ?Sized> Serialize<__S> for AsyncWrite