pub struct AtomicCopy {
pub src: String,
pub dest_dir: String,
pub rename: Option<String>,
pub location: Location,
}Fields
src: Stringdest_dir: Stringrename: Option<String>location: LocationTrait Implementations
Sourceimpl Archive for AtomicCopy
impl Archive for AtomicCopy
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedAtomicCopy
type Archived = ArchivedAtomicCopy
The archived representation of this type. Read more
Sourcetype Resolver = AtomicCopyResolver
type Resolver = AtomicCopyResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for AtomicCopy
impl BlockingArchive for AtomicCopy
Sourceimpl Debug for AtomicCopy
impl Debug for AtomicCopy
Sourceimpl<__D: Fallible + ?Sized> Deserialize<AtomicCopy, __D> for Archived<AtomicCopy>
impl<__D: Fallible + ?Sized> Deserialize<AtomicCopy, __D> for Archived<AtomicCopy>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<AtomicCopy, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<AtomicCopy, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for AtomicCopy
impl MessageId for AtomicCopy
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for AtomicCopy
impl<__S: Fallible + ?Sized> Serialize<__S> for AtomicCopy