pub struct CreateDirMessage {
pub path: String,
pub location: Location,
}Fields
path: Stringlocation: LocationTrait Implementations
Sourceimpl Archive for CreateDirMessage
impl Archive for CreateDirMessage
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCreateDirMessage
type Archived = ArchivedCreateDirMessage
The archived representation of this type. Read more
Sourcetype Resolver = CreateDirMessageResolver
type Resolver = CreateDirMessageResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for CreateDirMessage
impl BlockingArchive for CreateDirMessage
Sourceimpl Debug for CreateDirMessage
impl Debug for CreateDirMessage
Sourceimpl<__D: Fallible + ?Sized> Deserialize<CreateDirMessage, __D> for Archived<CreateDirMessage>
impl<__D: Fallible + ?Sized> Deserialize<CreateDirMessage, __D> for Archived<CreateDirMessage>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CreateDirMessage, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CreateDirMessage, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for CreateDirMessage
impl MessageId for CreateDirMessage
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for CreateDirMessage
impl<__S: Fallible + ?Sized> Serialize<__S> for CreateDirMessage