pub struct NextEntry(pub DirHandle);Tuple Fields
0: DirHandleTrait Implementations
Sourceimpl Archive for NextEntrywhere
DirHandle: Archive,
impl Archive for NextEntrywhere
DirHandle: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedNextEntry
type Archived = ArchivedNextEntry
The archived representation of this type. Read more
Sourcetype Resolver = NextEntryResolver
type Resolver = NextEntryResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for NextEntry
impl BlockingArchive for NextEntry