pub struct OpenDirMessage {
pub path: String,
pub location: Location,
}Fields
path: Stringlocation: LocationTrait Implementations
Sourceimpl Archive for OpenDirMessage
impl Archive for OpenDirMessage
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedOpenDirMessage
type Archived = ArchivedOpenDirMessage
The archived representation of this type. Read more
Sourcetype Resolver = OpenDirMessageResolver
type Resolver = OpenDirMessageResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for OpenDirMessage
impl BlockingArchive for OpenDirMessage
Sourceimpl Debug for OpenDirMessage
impl Debug for OpenDirMessage
Sourceimpl<__D: Fallible + ?Sized> Deserialize<OpenDirMessage, __D> for Archived<OpenDirMessage>
impl<__D: Fallible + ?Sized> Deserialize<OpenDirMessage, __D> for Archived<OpenDirMessage>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<OpenDirMessage, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<OpenDirMessage, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for OpenDirMessage
impl MessageId for OpenDirMessage
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for OpenDirMessage
impl<__S: Fallible + ?Sized> Serialize<__S> for OpenDirMessage