pub struct OpenFileMessage {
pub path: String,
pub location: Location,
pub flags: OpenFlags,
}Fields
path: Stringlocation: Locationflags: OpenFlagsTrait Implementations
Sourceimpl Archive for OpenFileMessage
impl Archive for OpenFileMessage
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedOpenFileMessage
type Archived = ArchivedOpenFileMessage
The archived representation of this type. Read more
Sourcetype Resolver = OpenFileMessageResolver
type Resolver = OpenFileMessageResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for OpenFileMessage
impl BlockingArchive for OpenFileMessage
Sourceimpl Debug for OpenFileMessage
impl Debug for OpenFileMessage
Sourceimpl<__D: Fallible + ?Sized> Deserialize<OpenFileMessage, __D> for Archived<OpenFileMessage>
impl<__D: Fallible + ?Sized> Deserialize<OpenFileMessage, __D> for Archived<OpenFileMessage>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<OpenFileMessage, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<OpenFileMessage, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for OpenFileMessage
impl MessageId for OpenFileMessage
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for OpenFileMessage
impl<__S: Fallible + ?Sized> Serialize<__S> for OpenFileMessage