pub struct RegisterAppResources {
pub app_id: AppId,
pub root: AppResourcesRoot,
pub app_dir: String,
}Fields
app_id: AppIdroot: AppResourcesRootapp_dir: StringTrait Implementations
Sourceimpl Archive for RegisterAppResources
impl Archive for RegisterAppResources
Sourcetype Archived = ArchivedRegisterAppResources
type Archived = ArchivedRegisterAppResources
The archived representation of this type. Read more
Sourcetype Resolver = RegisterAppResourcesResolver
type Resolver = RegisterAppResourcesResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl Debug for RegisterAppResources
impl Debug for RegisterAppResources
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RegisterAppResources, __D> for Archived<RegisterAppResources>where
WithAppId: ArchiveWith<AppId> + DeserializeWith<<WithAppId as ArchiveWith<AppId>>::Archived, AppId, __D>,
AppResourcesRoot: Archive,
<AppResourcesRoot as Archive>::Archived: Deserialize<AppResourcesRoot, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
impl<__D: Fallible + ?Sized> Deserialize<RegisterAppResources, __D> for Archived<RegisterAppResources>where
WithAppId: ArchiveWith<AppId> + DeserializeWith<<WithAppId as ArchiveWith<AppId>>::Archived, AppId, __D>,
AppResourcesRoot: Archive,
<AppResourcesRoot as Archive>::Archived: Deserialize<AppResourcesRoot, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RegisterAppResources, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RegisterAppResources, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for RegisterAppResources
impl MessageId for RegisterAppResources
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for RegisterAppResourceswhere
WithAppId: SerializeWith<AppId, __S>,
AppResourcesRoot: Serialize<__S>,
String: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for RegisterAppResourceswhere
WithAppId: SerializeWith<AppId, __S>,
AppResourcesRoot: Serialize<__S>,
String: Serialize<__S>,