pub struct Remove {
pub path: String,
pub location: Location,
}Fields
path: Stringlocation: LocationTrait Implementations
Sourceimpl Archive for Remove
impl Archive for Remove
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRemove
type Archived = ArchivedRemove
The archived representation of this type. Read more
Sourcetype Resolver = RemoveResolver
type Resolver = RemoveResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for Remove
impl BlockingArchive for Remove