pub struct RemoveAppData {
pub app_id: AppId,
}Expand description
Remove all AppData for app_id, not just the caller’s own (unlike Remove,
which is scoped to the calling app). Wipes the app’s persisted data, including
any stored seed.
Fields
app_id: AppIdTrait Implementations
Sourceimpl Archive for RemoveAppDatawhere
WithAppId: ArchiveWith<AppId>,
impl Archive for RemoveAppDatawhere
WithAppId: ArchiveWith<AppId>,
Sourcetype Archived = ArchivedRemoveAppData
type Archived = ArchivedRemoveAppData
The archived representation of this type. Read more
Sourcetype Resolver = RemoveAppDataResolver
type Resolver = RemoveAppDataResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl BlockingArchive for RemoveAppData
impl BlockingArchive for RemoveAppData
Sourceimpl Debug for RemoveAppData
impl Debug for RemoveAppData
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RemoveAppData, __D> for Archived<RemoveAppData>
impl<__D: Fallible + ?Sized> Deserialize<RemoveAppData, __D> for Archived<RemoveAppData>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RemoveAppData, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RemoveAppData, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for RemoveAppData
impl MessageId for RemoveAppData
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for RemoveAppDatawhere
WithAppId: SerializeWith<AppId, __S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for RemoveAppDatawhere
WithAppId: SerializeWith<AppId, __S>,