pub struct Rename {
pub location: Location,
pub from: String,
pub to: String,
}Fields
location: Locationfrom: Stringto: StringTrait Implementations
Sourceimpl Archive for Rename
impl Archive for Rename
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRename
type Archived = ArchivedRename
The archived representation of this type. Read more
Sourcetype Resolver = RenameResolver
type Resolver = RenameResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for Rename
impl BlockingArchive for Rename