pub struct SeekFile {
pub file: FileHandle,
pub pos: SeekFrom,
}Fields
file: FileHandlepos: SeekFromTrait Implementations
Sourceimpl Archive for SeekFilewhere
FileHandle: Archive,
SeekFrom: Archive,
impl Archive for SeekFilewhere
FileHandle: Archive,
SeekFrom: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSeekFile
type Archived = ArchivedSeekFile
The archived representation of this type. Read more
Sourcetype Resolver = SeekFileResolver
type Resolver = SeekFileResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for SeekFile
impl BlockingArchive for SeekFile
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SeekFile, __D> for Archived<SeekFile>where
FileHandle: Archive,
<FileHandle as Archive>::Archived: Deserialize<FileHandle, __D>,
SeekFrom: Archive,
<SeekFrom as Archive>::Archived: Deserialize<SeekFrom, __D>,
impl<__D: Fallible + ?Sized> Deserialize<SeekFile, __D> for Archived<SeekFile>where
FileHandle: Archive,
<FileHandle as Archive>::Archived: Deserialize<FileHandle, __D>,
SeekFrom: Archive,
<SeekFrom as Archive>::Archived: Deserialize<SeekFrom, __D>,