pub struct SetLen {
pub handle: FileHandle,
pub len: u64,
}Fields
handle: FileHandlelen: u64Trait Implementations
Sourceimpl Archive for SetLenwhere
FileHandle: Archive,
u64: Archive,
impl Archive for SetLenwhere
FileHandle: Archive,
u64: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSetLen
type Archived = ArchivedSetLen
The archived representation of this type. Read more
Sourcetype Resolver = SetLenResolver
type Resolver = SetLenResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for SetLen
impl BlockingArchive for SetLen
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SetLen, __D> for Archived<SetLen>where
FileHandle: Archive,
<FileHandle as Archive>::Archived: Deserialize<FileHandle, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
impl<__D: Fallible + ?Sized> Deserialize<SetLen, __D> for Archived<SetLen>where
FileHandle: Archive,
<FileHandle as Archive>::Archived: Deserialize<FileHandle, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,