pub struct SetMtime {
pub handle: FileHandle,
pub datetime: DateTime,
}Fields
handle: FileHandledatetime: DateTimeTrait Implementations
Sourceimpl Archive for SetMtimewhere
FileHandle: Archive,
DateTime: Archive,
impl Archive for SetMtimewhere
FileHandle: Archive,
DateTime: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSetMtime
type Archived = ArchivedSetMtime
The archived representation of this type. Read more
Sourcetype Resolver = SetMtimeResolver
type Resolver = SetMtimeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for SetMtime
impl BlockingArchive for SetMtime
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SetMtime, __D> for Archived<SetMtime>where
FileHandle: Archive,
<FileHandle as Archive>::Archived: Deserialize<FileHandle, __D>,
DateTime: Archive,
<DateTime as Archive>::Archived: Deserialize<DateTime, __D>,
impl<__D: Fallible + ?Sized> Deserialize<SetMtime, __D> for Archived<SetMtime>where
FileHandle: Archive,
<FileHandle as Archive>::Archived: Deserialize<FileHandle, __D>,
DateTime: Archive,
<DateTime as Archive>::Archived: Deserialize<DateTime, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SetMtime, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SetMtime, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SetMtimewhere
FileHandle: Serialize<__S>,
DateTime: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for SetMtimewhere
FileHandle: Serialize<__S>,
DateTime: Serialize<__S>,