pub struct SubscribeFilesystemEvent(pub Location);Tuple Fields
0: LocationTrait Implementations
Sourceimpl Archive for SubscribeFilesystemEventwhere
Location: Archive,
impl Archive for SubscribeFilesystemEventwhere
Location: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSubscribeFilesystemEvent
type Archived = ArchivedSubscribeFilesystemEvent
The archived representation of this type. Read more
Sourcetype Resolver = SubscribeFilesystemEventResolver
type Resolver = SubscribeFilesystemEventResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for SubscribeFilesystemEvent
impl Debug for SubscribeFilesystemEvent
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SubscribeFilesystemEvent, __D> for Archived<SubscribeFilesystemEvent>
impl<__D: Fallible + ?Sized> Deserialize<SubscribeFilesystemEvent, __D> for Archived<SubscribeFilesystemEvent>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SubscribeFilesystemEvent, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SubscribeFilesystemEvent, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for SubscribeFilesystemEvent
impl MessageId for SubscribeFilesystemEvent
Sourceimpl ScalarSubscription for SubscribeFilesystemEvent
impl ScalarSubscription for SubscribeFilesystemEvent
type Event = FileSystemEvent
type Error = Infallible
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SubscribeFilesystemEventwhere
Location: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for SubscribeFilesystemEventwhere
Location: Serialize<__S>,