pub struct TruncateFile(pub FileHandle);Tuple Fields
0: FileHandleTrait Implementations
Sourceimpl Archive for TruncateFilewhere
FileHandle: Archive,
impl Archive for TruncateFilewhere
FileHandle: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedTruncateFile
type Archived = ArchivedTruncateFile
The archived representation of this type. Read more
Sourcetype Resolver = TruncateFileResolver
type Resolver = TruncateFileResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for TruncateFile
impl BlockingArchive for TruncateFile
Sourceimpl Debug for TruncateFile
impl Debug for TruncateFile
Sourceimpl<__D: Fallible + ?Sized> Deserialize<TruncateFile, __D> for Archived<TruncateFile>
impl<__D: Fallible + ?Sized> Deserialize<TruncateFile, __D> for Archived<TruncateFile>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<TruncateFile, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<TruncateFile, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for TruncateFile
impl MessageId for TruncateFile
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for TruncateFilewhere
FileHandle: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for TruncateFilewhere
FileHandle: Serialize<__S>,