pub struct Date {
pub year: u16,
pub month: u16,
pub day: u16,
}Fields
year: u16month: u16day: u16Trait Implementations
Sourceimpl Archive for Datewhere
u16: Archive,
impl Archive for Datewhere
u16: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedDate
type Archived = ArchivedDate
The archived representation of this type. Read more
Sourcetype Resolver = DateResolver
type Resolver = DateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Ord for Date
impl Ord for Date
Sourceimpl PartialOrd for Date
impl PartialOrd for Date
impl Copy for Date
impl Eq for Date
impl StructuralPartialEq for Date