pub struct DateTime {
pub date: Date,
pub time: Time,
}Fields
date: Datetime: TimeTrait Implementations
Sourceimpl Archive for DateTime
impl Archive for DateTime
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedDateTime
type Archived = ArchivedDateTime
The archived representation of this type. Read more
Sourcetype Resolver = DateTimeResolver
type Resolver = DateTimeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Ord for DateTime
impl Ord for DateTime
Sourceimpl PartialOrd for DateTime
impl PartialOrd for DateTime
impl Copy for DateTime
impl Eq for DateTime
impl StructuralPartialEq for DateTime