pub struct DirEntry {
pub name: String,
pub len: u64,
pub modified: DateTime,
pub is_dir: bool,
pub is_file: bool,
}Fields
name: Stringlen: u64modified: DateTimeis_dir: boolis_file: boolTrait Implementations
Sourceimpl Archive for DirEntry
impl Archive for DirEntry
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedDirEntry
type Archived = ArchivedDirEntry
The archived representation of this type. Read more
Sourcetype Resolver = DirEntryResolver
type Resolver = DirEntryResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.