File

Struct File 

pub struct File<P: CheckedPermissions + MessageAllowed<CloseFile>> { /* private fields */ }

Implementations

Source

impl<P: CheckedPermissions + MessageAllowed<CloseFile>> File<P>

pub fn truncate(&mut self) -> Result<(), Error>

  • Permission: os/fs / CloseFile

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / TruncateFile

    Groups: file-system.mutate-delete

    Sender policy: signed

    Grant timing: location-grant

pub fn set_len(&mut self, len: u64) -> Result<(), Error>

  • Permission: os/fs / CloseFile

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / SetLen

    Groups: file-system.mutate-delete

    Sender policy: signed

    Grant timing: location-grant

pub fn metadata(&self) -> Result<Metadata, Error>

  • Permission: os/fs / CloseFile

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / GetMetadata

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

pub fn set_mtime(&mut self, datetime: DateTime) -> Result<(), Error>

  • Permission: os/fs / CloseFile

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / SetMtime

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

pub fn async_read(&mut self, read_len: usize) -> AsyncRead

Permission: os/fs / CloseFile

Groups: file-system.file-handles

Sender policy: signed

Grant timing: location-grant

Prepare a message that can be sent with slint_keyos_platform::async_archive Less efficient than a regular read() May return less bytes than requested. Returns an empty buffer on EOF

pub fn async_write(&mut self, buffer: Vec<u8>) -> AsyncWrite

Permission: os/fs / CloseFile

Groups: file-system.file-handles

Sender policy: signed

Grant timing: location-grant

Prepare a message that can be sent with slint_keyos_platform::async_archive Less efficient than a regular write() The actual bytes written is returned, may be less than the buffer size

pub fn async_copy_block_to( &mut self, to: &mut Self, len: usize, ) -> AsyncCopyBlock

Permission: os/fs / CloseFile

Groups: file-system.file-handles

Sender policy: signed

Grant timing: location-grant

Prepare a message that can be sent with slint_keyos_platform::async_scalar Efficiently copies between two open files. Returns the numebr of actually copied bytes. Returns Ok(0) on EOF

pub fn copy_block_to( &mut self, to: &mut Self, len: usize, ) -> Result<usize, Error>

  • Permission: os/fs / CloseFile

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / AsyncCopyBlock

    Groups: file-system.read-write

    Sender policy: signed

    Grant timing: location-grant

pub fn overwrite(&mut self, buf: &[u8]) -> Result<(), Error>

  • Permission: os/fs / CloseFile

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / SeekFile

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / WriteFile

    Groups: file-system.read-write

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / TruncateFile

    Groups: file-system.mutate-delete

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / Flush

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

pub fn copy_to(&mut self, to: &mut Self) -> Result<(), Error>

  • Permission: os/fs / CloseFile

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / SeekFile

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / WriteFile

    Groups: file-system.read-write

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / TruncateFile

    Groups: file-system.mutate-delete

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / AsyncCopyBlock

    Groups: file-system.read-write

    Sender policy: signed

    Grant timing: location-grant