FileSystem

Struct FileSystem 

pub struct FileSystem<P: CheckedPermissions> { /* private fields */ }
Client handle for the filesystem server.

This is the filesystem crate’s high-level API surface. It owns a checked connection to os/fs, enforces location access checks, and creates File and Dir handles for file and directory operations.

Implementations

Source

impl<P: CheckedPermissions> FileSystem<P>

pub fn open_file( &self, path: impl Into<String>, location: Location, flags: OpenFlags, ) -> Result<File<P>, Error>

  • Permission: os/fs / OpenFileMessage

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / CloseFile

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

pub fn open_dir( &self, path: impl Into<String>, location: Location, ) -> Result<Dir<P>, Error>

  • Permission: os/fs / OpenDirMessage

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / CloseDir

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

pub fn create_dir( &self, path: impl Into<String>, location: Location, ) -> Result<Dir<P>, Error>

  • Permission: os/fs / CreateDirMessage

    Groups: file-system.mutate-delete

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / CloseDir

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

pub fn create_dir_async( &self, path: impl Into<String>, location: Location, ) -> Result<CreateDirMessage, Error>

  • Permission: os/fs / CreateDirMessage

    Groups: file-system.mutate-delete

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / CloseDir

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

pub fn ensure_parent_dir_exists( &self, path: &str, location: Location, ) -> Result<(), Error>

  • Permission: os/fs / CreateDirMessage

    Groups: file-system.mutate-delete

    Sender policy: signed

    Grant timing: location-grant

  • Permission: os/fs / CloseDir

    Groups: file-system.file-handles

    Sender policy: signed

    Grant timing: location-grant

pub fn remove( &self, path: impl Into<String>, location: Location, ) -> Result<(), Error>

Permission: os/fs / Remove

Groups: file-system.mutate-delete

Sender policy: signed

Grant timing: location-grant

pub fn remove_async( &self, path: impl Into<String>, location: Location, ) -> Result<Remove, Error>

Permission: os/fs / Remove

Groups: file-system.mutate-delete

Sender policy: signed

Grant timing: location-grant

pub fn atomic_copy( &self, src: impl Into<String>, dest_dir: impl Into<String>, rename: Option<impl Into<String>>, location: Location, ) -> Result<(), Error>

Permission: os/fs / AtomicCopy

Groups: file-system.mutate-delete

Sender policy: signed

Grant timing: location-grant

Copy a source file/directory to a destination directory. If source is a directory, the copy is recursive.

Optionally, the copied file/directory can be renamed by providing the rename argument.

The destination directory must be empty; copying into a non-empty directory returns Error::FileAlreadyExists.

pub fn metadata( &self, path: impl Into<String>, location: Location, ) -> Result<Metadata, Error>

Permission: os/fs / GetMetadata

Groups: file-system.file-handles

Sender policy: signed

Grant timing: location-grant

pub fn rename( &self, from: impl Into<String>, to: impl Into<String>, location: Location, ) -> Result<(), Error>

Permission: os/fs / Rename

Groups: file-system.mutate-delete

Sender policy: signed

Grant timing: location-grant

pub fn rename_async( &self, from: impl Into<String>, to: impl Into<String>, location: Location, ) -> Result<Rename, Error>

Permission: os/fs / Rename

Groups: file-system.mutate-delete

Sender policy: signed

Grant timing: location-grant

pub fn map_file( &self, location: Location, path: impl Into<String>, ) -> Result<MemoryRange, Error>

Permission: none

pub fn register_app_resources( &self, app_id: AppId, root: AppResourcesRoot, app_dir: impl Into<String>, ) -> Result<(), Error>

Permission: os/fs / RegisterAppResources

Groups: file-system.app-resource-registration

Sender policy: static-server

Grant timing: policy-only

pub fn read_blocks( &mut self, location: Location, block_index: u32, block_count: usize, buf: MemoryRange, ) -> Result<usize, Error>

Permission: os/fs / ReadBlocks

Groups: file-system.raw-blocks

Sender policy: static-server

Grant timing: policy-only

pub fn write_blocks( &mut self, location: Location, block_index: u32, block_count: usize, buf: MemoryRange, ) -> Result<usize, Error>

Permission: os/fs / WriteBlocks

Groups: file-system.raw-blocks

Sender policy: static-server

Grant timing: policy-only

pub fn flush(&mut self, location: Location) -> Result<(), Error>

Permission: os/fs / FlushFs

Groups: file-system.file-handles

Sender policy: signed

Grant timing: location-grant

pub fn block_count(&self, location: Location) -> Result<usize, Error>

Permission: os/fs / BlockCount

Groups: file-system.raw-blocks

Sender policy: static-server

Grant timing: policy-only

pub fn format_encrypted_volume(&self)

Permission: os/fs / FormatEncryptedVolume

Groups: file-system.volume-admin

Sender policy: static-server

Grant timing: policy-only

pub fn subscribe_filesystem_events<S>( &self, listener: &mut ServerContext<S>, location: Location, )

Permission: os/fs / SubscribeFilesystemEvent

Groups: file-system.file-handles

Sender policy: signed

Grant timing: location-grant

pub fn wait_for_filesystem(&self, location: Location)

Permission: os/fs / SubscribeFilesystemEvent

Groups: file-system.file-handles

Sender policy: signed

Grant timing: location-grant

pub fn mount_airlock(&mut self) -> Result<(), Error>

Permission: os/fs / MountAirlock

Groups: file-system.volume-admin

Sender policy: static-server

Grant timing: policy-only

pub fn unmount_airlock(&mut self) -> Result<(), Error>

Permission: os/fs / MountAirlock

Groups: file-system.volume-admin

Sender policy: static-server

Grant timing: policy-only

pub fn format_airlock(&mut self) -> Result<(), Error>

Permission: os/fs / FormatAirlock

Groups: file-system.volume-admin

Sender policy: static-server

Grant timing: policy-only