pub struct MappedFileInTheirSpace {
pub addr: usize,
pub size: usize,
}Fields
addr: usizesize: usizeTrait Implementations
Sourceimpl Archive for MappedFileInTheirSpacewhere
usize: Archive,
impl Archive for MappedFileInTheirSpacewhere
usize: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedMappedFileInTheirSpace
type Archived = ArchivedMappedFileInTheirSpace
The archived representation of this type. Read more
Sourcetype Resolver = MappedFileInTheirSpaceResolver
type Resolver = MappedFileInTheirSpaceResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for MappedFileInTheirSpace
impl Debug for MappedFileInTheirSpace
Sourceimpl<__D: Fallible + ?Sized> Deserialize<MappedFileInTheirSpace, __D> for Archived<MappedFileInTheirSpace>
impl<__D: Fallible + ?Sized> Deserialize<MappedFileInTheirSpace, __D> for Archived<MappedFileInTheirSpace>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<MappedFileInTheirSpace, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<MappedFileInTheirSpace, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for MappedFileInTheirSpacewhere
usize: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for MappedFileInTheirSpacewhere
usize: Serialize<__S>,