pub struct Metadata {
pub created: DateTime,
pub accessed: Date,
pub modified: DateTime,
pub size: u64,
pub is_dir: bool,
}Fields
created: DateTimeaccessed: Datemodified: DateTimesize: u64is_dir: boolTrait Implementations
Sourceimpl Archive for Metadata
impl Archive for Metadata
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedMetadata
type Archived = ArchivedMetadata
The archived representation of this type. Read more
Sourcetype Resolver = MetadataResolver
type Resolver = MetadataResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
impl Copy for Metadata