pub struct Time {
pub hour: u16,
pub min: u16,
pub sec: u16,
pub millis: u16,
}Fields
hour: u16min: u16sec: u16millis: u16Trait Implementations
Sourceimpl Archive for Timewhere
u16: Archive,
impl Archive for Timewhere
u16: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedTime
type Archived = ArchivedTime
The archived representation of this type. Read more
Sourcetype Resolver = TimeResolver
type Resolver = TimeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Ord for Time
impl Ord for Time
Sourceimpl PartialOrd for Time
impl PartialOrd for Time
impl Copy for Time
impl Eq for Time
impl StructuralPartialEq for Time