pub struct MapFileMessage {
pub path: String,
pub location: Location,
}Fields
path: Stringlocation: LocationTrait Implementations
Sourceimpl Archive for MapFileMessagewhere
String: Archive,
Location: Archive,
impl Archive for MapFileMessagewhere
String: Archive,
Location: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedMapFileMessage
type Archived = ArchivedMapFileMessage
The archived representation of this type. Read more
Sourcetype Resolver = MapFileMessageResolver
type Resolver = MapFileMessageResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for MapFileMessage
impl BlockingArchive for MapFileMessage
Sourcetype Response = Result<MappedFileInTheirSpace, Error>
type Response = Result<MappedFileInTheirSpace, Error>
response type for this message
Sourceimpl Debug for MapFileMessage
impl Debug for MapFileMessage
Sourceimpl<__D: Fallible + ?Sized> Deserialize<MapFileMessage, __D> for Archived<MapFileMessage>
impl<__D: Fallible + ?Sized> Deserialize<MapFileMessage, __D> for Archived<MapFileMessage>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<MapFileMessage, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<MapFileMessage, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for MapFileMessage
impl MessageId for MapFileMessage
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for MapFileMessagewhere
String: Serialize<__S>,
Location: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for MapFileMessagewhere
String: Serialize<__S>,
Location: Serialize<__S>,