pub struct File<P: CheckedPermissions + MessageAllowed<CloseFile>> { /* private fields */ }Implementations
Sourceimpl<P: CheckedPermissions + MessageAllowed<CloseFile>> File<P>
impl<P: CheckedPermissions + MessageAllowed<CloseFile>> File<P>
pub fn truncate(&mut self) -> Result<(), Error>where
P: MessageAllowed<TruncateFile>,
pub fn set_len(&mut self, len: u64) -> Result<(), Error>where
P: MessageAllowed<SetLen>,
pub fn metadata(&self) -> Result<Metadata, Error>where
P: MessageAllowed<GetMetadata>,
pub fn set_mtime(&mut self, datetime: DateTime) -> Result<(), Error>where
P: MessageAllowed<SetMtime>,
Sourcepub fn async_read(&mut self, read_len: usize) -> AsyncRead
pub fn async_read(&mut self, read_len: usize) -> AsyncRead
Prepare a message that can be sent with slint_keyos_platform::async_archive Less efficient than a regular read() May return less bytes than requested. Returns an empty buffer on EOF
Sourcepub fn async_write(&mut self, buffer: Vec<u8>) -> AsyncWrite
pub fn async_write(&mut self, buffer: Vec<u8>) -> AsyncWrite
Prepare a message that can be sent with slint_keyos_platform::async_archive Less efficient than a regular write() The actual bytes written is returned, may be less than the buffer size
Sourcepub fn async_copy_block_to(
&mut self,
to: &mut Self,
len: usize,
) -> AsyncCopyBlock
pub fn async_copy_block_to( &mut self, to: &mut Self, len: usize, ) -> AsyncCopyBlock
Prepare a message that can be sent with slint_keyos_platform::async_scalar Efficiently copies between two open files. Returns the numebr of actually copied bytes. Returns Ok(0) on EOF
pub fn copy_block_to(
&mut self,
to: &mut Self,
len: usize,
) -> Result<usize, Error>where
P: MessageAllowed<AsyncCopyBlock>,
pub fn overwrite(&mut self, buf: &[u8]) -> Result<(), Error>where
P: MessageAllowed<SeekFile> + MessageAllowed<WriteFile> + MessageAllowed<TruncateFile> + MessageAllowed<Flush>,
pub fn copy_to(&mut self, to: &mut Self) -> Result<(), Error>where
P: MessageAllowed<SeekFile> + MessageAllowed<WriteFile> + MessageAllowed<TruncateFile> + MessageAllowed<AsyncCopyBlock>,